package de.hsrm.jakartaee.knauf.statelessmaven.web.test;

import jakarta.ejb.EJB;

import java.io.File;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.junit5.ArquillianExtension;
import org.jboss.shrinkwrap.api.Archive;
import org.jboss.shrinkwrap.api.ShrinkWrap;
import org.jboss.shrinkwrap.api.importer.ZipImporter;
import org.jboss.shrinkwrap.api.spec.EnterpriseArchive;
import org.jboss.shrinkwrap.api.spec.JavaArchive;
import org.jboss.shrinkwrap.api.spec.WebArchive;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;

import de.hsrm.jakartaee.knauf.statelessmaven.ejb.GeometricModelLocal;

@ExtendWith(ArquillianExtension.class)
public class GeometricModelBeanIT
{
  @EJB
  private GeometricModelLocal geometricModelLocal;
 
  @Deployment
  public static Archive<?> getEarArchive() 
  {
    EnterpriseArchive ear = ShrinkWrap.create(EnterpriseArchive.class, "StatelessMaven-ear.ear");
    
    File f = new File("../ejb/target/StatelessMaven-ejb.jar");
    JavaArchive ejbJar = ShrinkWrap.create(ZipImporter.class, "StatelessMaven-ejb.jar").
          importFrom(f).as(JavaArchive.class) ;
    ear.addAsModule(ejbJar);
     
    
    f = new File("../web/target/StatelessMaven-web.war");
    WebArchive war = ShrinkWrap.create(ZipImporter.class, "StatelessMaven-web.war").
           importFrom(f).as(WebArchive.class) ;
    ear.addAsModule(war);
    
    war.addPackage("de.hsrm.jakartaee.knauf.statelessmaven.web.test");
      
    //Export der EAR-Datei für Diagnosezwecke:
    //ear.as(org.jboss.shrinkwrap.api.exporter.ZipExporter.class).exportTo(new File("c:\\temp\\test.ear"), true);
    
    return ear;
  }
  
  @Test
  public void testCuboidSurface()
  {
    System.out.println("Testing cuboid surface...");
   
    double surface = geometricModelLocal.computeCuboidSurface(1, 2, 3);
    //Hier muss ein "Delta" angegeben werden für Abweichung durch Rundungsungenauigkeit. Das kann hier nicht zuschlagen, deshalb können wir Delta = 0 angeben.
    Assertions.assertEquals(22, surface, 0);
  }
  
  @Test
  public void testCuboidVolume()
  {
    System.out.println("Testing cuboid volume...");
                
    double volume = geometricModelLocal.computeCuboidVolume(1, 2, 3);
    //Hier muss ein "Delta" angegeben werden für Abweichung durch Rundungsungenauigkeit. Das kann hier nicht zuschlagen, deshalb können wir Delta = 0 angeben.
    Assertions.assertEquals(6, volume, 0);
  }
}